Mixed Integer Parallel Efficient Global Optimization Algorithm
=======================

The bayesian optimization algorithm is a surrogate-based optimizer that can
optimize expensive black-box functions. This implementation is specifically
tuned to optimize deep neural networks. It is able to handle parallel 
evaluations on multiple GPUs, and can use a Random Forest surrogate model.

For additional details see our paper: <https://coming_soon>`_.

